
from django.core.urlresolvers import reverse
from django.views.generic import TemplateView, CreateView, FormView

from django.shortcuts import render_to_response
from django.template import RequestContext

from feedback_form import forms

class CompletedPage(TemplateView):
    template_name = "feedback_form/feedback_done.html"

class ContactFormMixin(object):
    """
    Form view that sends email when form is valid. You'll need
    to define your own form_class and template_name.
    """    
    def form_valid(self, form):
        form.send_email(self.request)
        return super(ContactFormMixin, self).form_valid(form)

    def get_success_url(self):		
        return reverse("completed")

	def get_context_data(self, **kwargs):
		context = super(ContactFormObject, self).get_context_data(**kwargs)
		return context
	
class ContactFormView(ContactFormMixin, FormView):
  template_name="feedback_form/feedback.html"
  form_class=forms.ContactForm




from django.conf.urls.defaults import url, patterns
from feedback_form import views

urlpatterns = patterns('',
    url(r'^$', views.ContactFormView.as_view(), name="feedback"),
	url(r'^$', views.ContactFormView.as_view(), name="completed"),    
)



from django import forms
from django.conf import settings
from django.core.mail.message import EmailMessage
from django.template import loader
from django.utils.translation import ugettext_lazy as _
from feedback_form.settings import *
from django.contrib import messages
from django.http import HttpRequest

class BaseEmailFormObject(object):		
	#if settings.CONTACT_ADMINS_ONLY:
	if CONTACT_ADMINS_ONLY:
		recipient_list = [email for _, email in settings.ADMINS]
	else:
		recipient_list = [email for _, email in settings.MANAGERS]

	subject_template = 'feedback_form/email_subject.txt'
	message_template = 'feedback_form/email_template.txt'
	from_template = 'feedback_form/email_from.txt'

	def get_message(self):
		return loader.render_to_string(self.message_template, self.get_context())

	def get_from_email(self):
		return loader.render_to_string(self.from_template, self.get_context())

	def get_subject(self):
		subject = loader.render_to_string(self.subject_template, self.get_context())
		return ''.join(subject.splitlines())
		
	def get_request_meta(self):
		meta = {}
		meta['UP'] = self.request.META['REMOTE_ADDR']
		meta['USER_AGENT'] = self.request.META['HTTP_USER_AGENT']
		return meta	

	def get_context(self):
		if not self.is_valid():
			raise ValueError("Cannot generate Context when form is invalid.")
		data = self.cleaned_data
		if CONTACT_SEND_META_INFO:
			data['meta'] = self.get_request_meta()
		return data

	def get_message_dict(self):
		return {
			"from_email": self.get_from_email(),
			"to": self.recipient_list,
			"subject": self.get_subject(),			
			"body": self.get_message(),
		}

	def send_email(self, request, fail_silently=False):
		self.request = request

		if EmailMessage(**self.get_message_dict()).send(fail_silently=fail_silently):
			messages.success(request, _('Message is sent successufully!'))


class ContactForm(forms.Form, BaseEmailFormObject):
	"""
	Subclass this and declare your own fields.
	"""
	name = forms.CharField(label=_(u'Your name'), max_length=64)
	subject = forms.CharField(label=_(u'Subject'), max_length=128)
	email = forms.EmailField(label=_(u'Your email address'), max_length=200)
	body = forms.CharField(label=_(u'Your message'), widget=forms.Textarea(attrs={'cols':'30', 'rows':'5'}))


# -*- coding: utf-8 -*-
from django.conf import settings

CONTACT_ADMINS_ONLY = getattr(settings, 'CONTACT_ADMINS_ONLY', True)

CONTACT_SEND_META_INFO = getattr(settings, 'CONTACT_SEND_META_INFO', False)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup 

setup(
    name='django-simple-feedback-form',
    version=__import__('feedback_form').__version__,
    author='Artem Galichkin',
    author_email='doomer3d@gmail.com',
    packages=['feedback_form'],    
    url='https://github.com/DOOMer/django-simple-feedback-form',
    download_url='https://github.com/DOOMer/django-simple-feedback-form',
    license='LICENSE.txt',
    description='Simple feedback form for your django project.',
    long_description=open('README.rst').read(),
    install_requires=["Django >= 1.3.0",],
    include_package_data=True,
)